/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.vehicle.tree;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.model.FleetManager;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ui.support.NodeFactory;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.netbeans.spi.project.ui.support.NodeList;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataFolder;
import org.openide.nodes.Node;

/**
 *
 * @author Maciek Dulkiewicz & Wytse Visser
 */
@NodeFactory.Registration(projectType = "nl-cloudfarming-client-fleet")
public class VehicleCategoryNodeFactory implements NodeFactory {

    private static final String DIR_NAME = "Vehicles";
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.vehicle");

    @Override
    public NodeList<?> createNodes(Project project) {
        try {
            createDirectoryIfNotExists(project);
            DataFolder vehiclesFolder = DataFolder.findFolder(getVehicleDirectory(project));
            return NodeFactorySupport.fixedNodeList(new VehicleCategoryNode(
                    vehiclesFolder.getNodeDelegate(),
                    project));

        } catch (IOException ex) {
            LOGGER.log(Level.SEVERE, "Could not create subdirectory for vehicles", ex.getMessage());
            return NodeFactorySupport.fixedNodeList();
        }
    }

    private static void createDirectoryIfNotExists(Project project) throws IOException {
        FileObject fleetDir = getFleetDirectory(project);

        if (fleetDir.getFileObject(DIR_NAME) == null) {
            fleetDir.createFolder(DIR_NAME);
        }
    }

    private static FileObject getFleetDirectory(Project project) throws IOException {
        FileObject fleetDir = project.getProjectDirectory().getFileObject(FleetManager.FLEET_DIR);
        if (fleetDir == null) {
            fleetDir = project.getProjectDirectory().createFolder(FleetManager.FLEET_DIR);
        }

        return fleetDir;
    }

    public static FileObject getVehicleDirectory(Project project) throws IOException {
        createDirectoryIfNotExists(project);
        return project.getProjectDirectory().getFileObject(FleetManager.FLEET_DIR).getFileObject(DIR_NAME);
    }

    public static String getDirectoryName() {
        return DIR_NAME;
    }
}
