/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.vehicle.wizard;

import java.io.IOException;
import nl.cloudfarming.client.fleet.machine.MachineDataService;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardAction;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardFactory;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardIterator;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.model.VehicleManager;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

@NbBundle.Messages({"wizardTitle=New vehicle"})
public final class VehicleWizardAction extends MachineWizardAction {

    public VehicleWizardAction(Project project) {
        super(project, Bundle.wizardTitle());
    }

    @Override
    protected void createMachine(WizardDescriptor wiz) throws IOException {
        Vehicle vehicle = (Vehicle) wiz.getProperty(MachineWizardIterator.PROP_MACHINE);
        
        MachineDataService.Model model = (MachineDataService.Model) wiz.getProperty(MachineWizardIterator.PROP_MODEL);
       
        vehicle.setHorsepower((int) readProperty(Vehicle.PROP_HORSEPOWER, wiz, model));
        vehicle.setDisplacement((double) readProperty(Vehicle.PROP_DISPLACEMENT, wiz, model));
        vehicle.setFuelTankCapacity((int) readProperty(Vehicle.PROP_FUELTANKCAPACITY, wiz, model));

        addDynamicProperties(vehicle, wiz);

        Lookup.getDefault().lookup(VehicleManager.class).save(vehicle);
    }

    @Override
    public MachineWizardFactory getWizardFactory() {
        return new VehicleWizardFactory(getProject());
    }
}
